@@ -249,7 +249,7 @@ pub trait RawDecoder: 'static {
 /// A trait object using dynamic dispatch which is a sendable reference to the encoding,
 /// for code where the encoding is not known at compile-time.
 #[stable]
-pub type EncodingRef = &'static Encoding + Send + Sync;
+pub type EncodingRef = &'static (Encoding + Send + Sync);
 
 /// Character encoding.
 #[stable]
